@@ -27,7 +27,7 @@ class SetupCog(commands.Cog):
             await context.message.delete()
             context.bot.tree.copy_global_to(guild=context.guild)
             synced = await context.bot.tree.sync(guild=context.guild)
-            await context.send(f"Synced {len(synced)} commands.")
+            await context.send(f"Synced {len(synced)} commands from {platform.node()}.")
             role = discord.utils.get(self.client.guilds[0].roles, name="Dev")
             bot_member = discord.utils.get(self.client.get_all_members(), name="Doug Bot")
             if platform.node().lower() == "secureerase":
@@ -37,6 +37,7 @@ class SetupCog(commands.Cog):
                 print("Switching to Dev")
                 await bot_member.add_roles(role)
         except commands.errors.CommandInvokeError:
+            print("not able to delete")
             return
 
     @app_commands.command(name="clear")
